@@ -6,10 +6,10 @@
 #include <string.h>
 #include <R_ext/Lapack.h>
 
-SEXP get_dimnames(int nrow, int ncol,
+void get_dimnames(int nrow, int ncol,
                   int *irow1, int *irow2, int *irow,
                   int *icol1, int *icol2, int *icol,
-                  SEXP dimnames1_, SEXP dimnames2_);
+                  SEXP dimnames1_, SEXP dimnames2_, SEXP dimnames_);
 
 void get_pos(int nA, int nB, int k, int *i, int *j, int start);
 
